@@ -7,18 +7,18 @@ use futures::{future, Stream, stream};
 use hvcg_governance_openapi_catholic_polity::{Api, ApiNoContext, Client, ContextWrapperExt, models,
                       AddDeaneryResponse,
                       DeleteDeaneryResponse,
-                      GetAllDeaneriesResponse,
+                      GetDeaneriesResponse,
                       GetDeaneryByIdResponse,
                       UpdateDeaneryResponse,
                       AddDioceseResponse,
                       DeleteDioceseResponse,
-                      GetAllDiocesesResponse,
                       GetDioceseByIdResponse,
+                      GetDiocesesResponse,
                       UpdateDioceseResponse,
                       AddParishResponse,
                       DeleteParishResponse,
-                      GetAllParishesResponse,
                       GetParishByIdResponse,
+                      GetParishesResponse,
                       UpdateParishResponse,
                      };
 use clap::{App, Arg};
@@ -42,15 +42,15 @@ fn main() {
             .help("Sets the operation to run")
             .possible_values(&[
                 "DeleteDeanery",
-                "GetAllDeaneries",
+                "GetDeaneries",
                 "GetDeaneryById",
                 "DeleteDiocese",
-                "GetAllDioceses",
                 "GetDioceseById",
+                "GetDioceses",
                 "AddParish",
                 "DeleteParish",
-                "GetAllParishes",
                 "GetParishById",
+                "GetParishes",
                 "UpdateParish",
             ])
             .required(true)
@@ -105,13 +105,12 @@ fn main() {
         */
         Some("DeleteDeanery") => {
             let result = rt.block_on(client.delete_deanery(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
-        Some("GetAllDeaneries") => {
-            let result = rt.block_on(client.get_all_deaneries(
-                  None,
+        Some("GetDeaneries") => {
+            let result = rt.block_on(client.get_deaneries(
+                  Some("province_name_example".to_string()),
                   Some("name_example".to_string())
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
@@ -125,7 +124,6 @@ fn main() {
         /* Disabled because there's no example.
         Some("UpdateDeanery") => {
             let result = rt.block_on(client.update_deanery(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example"),
                   ???
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
@@ -141,14 +139,6 @@ fn main() {
         */
         Some("DeleteDiocese") => {
             let result = rt.block_on(client.delete_diocese(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
-            ));
-            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
-        },
-        Some("GetAllDioceses") => {
-            let result = rt.block_on(client.get_all_dioceses(
-                  None,
-                  Some("name_example".to_string())
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
@@ -158,10 +148,16 @@ fn main() {
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
+        Some("GetDioceses") => {
+            let result = rt.block_on(client.get_dioceses(
+                  Some("province_name_example".to_string()),
+                  Some("name_example".to_string())
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
         /* Disabled because there's no example.
         Some("UpdateDiocese") => {
             let result = rt.block_on(client.update_diocese(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example"),
                   ???
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
@@ -175,16 +171,6 @@ fn main() {
         },
         Some("DeleteParish") => {
             let result = rt.block_on(client.delete_parish(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
-            ));
-            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
-        },
-        Some("GetAllParishes") => {
-            let result = rt.block_on(client.get_all_parishes(
-                  None,
-                  Some("name_example".to_string()),
-                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
-                  Some(56)
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
@@ -194,9 +180,18 @@ fn main() {
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
+        Some("GetParishes") => {
+            let result = rt.block_on(client.get_parishes(
+                  Some("diocese_name_example".to_string()),
+                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
+                  Some("name_example".to_string()),
+                  Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
+                  Some(56)
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
         Some("UpdateParish") => {
             let result = rt.block_on(client.update_parish(
-                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example"),
                   None
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
