@@ -38,18 +38,18 @@ const ID_ENCODE_SET: &AsciiSet = &FRAGMENT_ENCODE_SET.add(b'|');
 use crate::{Api,
      AddDeaneryResponse,
      DeleteDeaneryResponse,
-     GetAllDeaneriesResponse,
+     GetDeaneriesResponse,
      GetDeaneryByIdResponse,
      UpdateDeaneryResponse,
      AddDioceseResponse,
      DeleteDioceseResponse,
-     GetAllDiocesesResponse,
      GetDioceseByIdResponse,
+     GetDiocesesResponse,
      UpdateDioceseResponse,
      AddParishResponse,
      DeleteParishResponse,
-     GetAllParishesResponse,
      GetParishByIdResponse,
+     GetParishesResponse,
      UpdateParishResponse
      };
 
@@ -504,14 +504,12 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_deanery(
         &self,
-        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteDeaneryResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/diocese/{id}",
+            "{}/mutation-api/diocese",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -590,11 +588,11 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn get_all_deaneries(
+    async fn get_deaneries(
         &self,
-        param_province: Option<models::EcclesiasticalProvince>,
+        param_province_name: Option<String>,
         param_name: Option<String>,
-        context: &C) -> Result<GetAllDeaneriesResponse, ApiError>
+        context: &C) -> Result<GetDeaneriesResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
@@ -605,9 +603,9 @@ impl<S, C> Api<C> for Client<S, C> where
         // Query parameters
         let query_string = {
             let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            if let Some(param_province) = param_province {
-                query_string.append_pair("province",
-                    &param_province.to_string());
+            if let Some(param_province_name) = param_province_name {
+                query_string.append_pair("provinceName",
+                    &param_province_name.to_string());
             }
             if let Some(param_name) = param_name {
                 query_string.append_pair("name",
@@ -668,20 +666,20 @@ impl<S, C> Api<C> for Client<S, C> where
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
                 let body = serde_json::from_str::<models::Deanery>(body)?;
-                Ok(GetAllDeaneriesResponse::SuccessfulOperation
+                Ok(GetDeaneriesResponse::SuccessfulOperation
                     (body)
                 )
             }
             400 => {
                 let body = response.into_body();
                 Ok(
-                    GetAllDeaneriesResponse::InvalidIDSupplied
+                    GetDeaneriesResponse::InvalidIDSupplied
                 )
             }
             404 => {
                 let body = response.into_body();
                 Ok(
-                    GetAllDeaneriesResponse::DeaneryNotFound
+                    GetDeaneriesResponse::DeaneryNotFound
                 )
             }
             code => {
@@ -711,7 +709,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/deanery/{id}",
+            "{}/query-api/deaneries/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -812,15 +810,13 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn update_deanery(
         &self,
-        param_id: uuid::Uuid,
         param_deanery: models::Deanery,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/deanery/{id}",
+            "{}/mutation-api/deanery",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1043,14 +1039,12 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_diocese(
         &self,
-        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteDioceseResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/deanery/{id}",
+            "{}/mutation-api/deanery",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1129,120 +1123,6 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn get_all_dioceses(
-        &self,
-        param_province: Option<models::EcclesiasticalProvince>,
-        param_name: Option<String>,
-        context: &C) -> Result<GetAllDiocesesResponse, ApiError>
-    {
-        let mut client_service = self.client_service.clone();
-        let mut uri = format!(
-            "{}/query-api/dioceses",
-            self.base_path
-        );
-
-        // Query parameters
-        let query_string = {
-            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            if let Some(param_province) = param_province {
-                query_string.append_pair("province",
-                    &param_province.to_string());
-            }
-            if let Some(param_name) = param_name {
-                query_string.append_pair("name",
-                    &param_name.to_string());
-            }
-            query_string.finish()
-        };
-        if !query_string.is_empty() {
-            uri += "?";
-            uri += &query_string;
-        }
-
-        let uri = match Uri::from_str(&uri) {
-            Ok(uri) => uri,
-            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
-        };
-
-        let mut request = match Request::builder()
-            .method("GET")
-            .uri(uri)
-            .body(Body::empty()) {
-                Ok(req) => req,
-                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
-        };
-
-        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
-        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
-            Ok(h) => h,
-            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
-        });
-
-        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
-            // Currently only authentication with Basic and Bearer are supported
-            match auth_data {
-                &AuthData::Bearer(ref bearer_header) => {
-                    let auth = swagger::auth::Header(bearer_header.clone());
-                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
-                        Ok(h) => h,
-                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
-                    };
-                    request.headers_mut().insert(
-                        hyper::header::AUTHORIZATION,
-                        header);
-                },
-                _ => {}
-            }
-        }
-
-        let mut response = client_service.call((request, context.clone()))
-            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
-
-        match response.status().as_u16() {
-            200 => {
-                let body = response.into_body();
-                let body = body
-                        .to_raw()
-                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
-                let body = str::from_utf8(&body)
-                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Diocese>(body)?;
-                Ok(GetAllDiocesesResponse::SuccessfulOperation
-                    (body)
-                )
-            }
-            400 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllDiocesesResponse::InvalidIDSupplied
-                )
-            }
-            404 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllDiocesesResponse::DioceseNotFound
-                )
-            }
-            code => {
-                let headers = response.headers().clone();
-                let body = response.into_body()
-                       .take(100)
-                       .to_raw().await;
-                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
-                    code,
-                    headers,
-                    match body {
-                        Ok(body) => match String::from_utf8(body) {
-                            Ok(body) => body,
-                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
-                        },
-                        Err(e) => format!("<Failed to read body: {}>", e),
-                    }
-                )))
-            }
-        }
-    }
-
     async fn get_diocese_by_id(
         &self,
         param_id: uuid::Uuid,
@@ -1250,7 +1130,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/diocese/{id}",
+            "{}/query-api/dioceses/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -1349,17 +1229,129 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
+    async fn get_dioceses(
+        &self,
+        param_province_name: Option<String>,
+        param_name: Option<String>,
+        context: &C) -> Result<GetDiocesesResponse, ApiError>
+    {
+        let mut client_service = self.client_service.clone();
+        let mut uri = format!(
+            "{}/query-api/dioceses",
+            self.base_path
+        );
+
+        // Query parameters
+        let query_string = {
+            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
+            if let Some(param_province_name) = param_province_name {
+                query_string.append_pair("provinceName",
+                    &param_province_name.to_string());
+            }
+            if let Some(param_name) = param_name {
+                query_string.append_pair("name",
+                    &param_name.to_string());
+            }
+            query_string.finish()
+        };
+        if !query_string.is_empty() {
+            uri += "?";
+            uri += &query_string;
+        }
+
+        let uri = match Uri::from_str(&uri) {
+            Ok(uri) => uri,
+            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
+        };
+
+        let mut request = match Request::builder()
+            .method("GET")
+            .uri(uri)
+            .body(Body::empty()) {
+                Ok(req) => req,
+                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
+        };
+
+        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
+        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
+        });
+
+        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
+            // Currently only authentication with Basic and Bearer are supported
+            match auth_data {
+                &AuthData::Bearer(ref bearer_header) => {
+                    let auth = swagger::auth::Header(bearer_header.clone());
+                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
+                        Ok(h) => h,
+                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
+                    };
+                    request.headers_mut().insert(
+                        hyper::header::AUTHORIZATION,
+                        header);
+                },
+                _ => {}
+            }
+        }
+
+        let mut response = client_service.call((request, context.clone()))
+            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
+
+        match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                let body = body
+                        .to_raw()
+                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
+                let body = str::from_utf8(&body)
+                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
+                let body = serde_json::from_str::<models::Diocese>(body)?;
+                Ok(GetDiocesesResponse::SuccessfulOperation
+                    (body)
+                )
+            }
+            400 => {
+                let body = response.into_body();
+                Ok(
+                    GetDiocesesResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    GetDiocesesResponse::DioceseNotFound
+                )
+            }
+            code => {
+                let headers = response.headers().clone();
+                let body = response.into_body()
+                       .take(100)
+                       .to_raw().await;
+                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
+                    code,
+                    headers,
+                    match body {
+                        Ok(body) => match String::from_utf8(body) {
+                            Ok(body) => body,
+                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
+                        },
+                        Err(e) => format!("<Failed to read body: {}>", e),
+                    }
+                )))
+            }
+        }
+    }
+
     async fn update_diocese(
         &self,
-        param_id: uuid::Uuid,
         param_diocese: models::Diocese,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/diocese/{id}",
+            "{}/mutation-api/diocese",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1586,14 +1578,12 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn delete_parish(
         &self,
-        param_id: uuid::Uuid,
         context: &C) -> Result<DeleteParishResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/parish/{id}",
+            "{}/mutation-api/parish",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -1672,130 +1662,6 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn get_all_parishes(
-        &self,
-        param_diocese: Option<models::Diocese>,
-        param_name: Option<String>,
-        param_offset: Option<uuid::Uuid>,
-        param_count: Option<i32>,
-        context: &C) -> Result<GetAllParishesResponse, ApiError>
-    {
-        let mut client_service = self.client_service.clone();
-        let mut uri = format!(
-            "{}/query-api/parishes",
-            self.base_path
-        );
-
-        // Query parameters
-        let query_string = {
-            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            if let Some(param_diocese) = param_diocese {
-                query_string.append_pair("diocese",
-                    &param_diocese.to_string());
-            }
-            if let Some(param_name) = param_name {
-                query_string.append_pair("name",
-                    &param_name.to_string());
-            }
-            if let Some(param_offset) = param_offset {
-                query_string.append_pair("offset",
-                    &param_offset.to_string());
-            }
-            if let Some(param_count) = param_count {
-                query_string.append_pair("count",
-                    &param_count.to_string());
-            }
-            query_string.finish()
-        };
-        if !query_string.is_empty() {
-            uri += "?";
-            uri += &query_string;
-        }
-
-        let uri = match Uri::from_str(&uri) {
-            Ok(uri) => uri,
-            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
-        };
-
-        let mut request = match Request::builder()
-            .method("GET")
-            .uri(uri)
-            .body(Body::empty()) {
-                Ok(req) => req,
-                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
-        };
-
-        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
-        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
-            Ok(h) => h,
-            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
-        });
-
-        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
-            // Currently only authentication with Basic and Bearer are supported
-            match auth_data {
-                &AuthData::Bearer(ref bearer_header) => {
-                    let auth = swagger::auth::Header(bearer_header.clone());
-                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
-                        Ok(h) => h,
-                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
-                    };
-                    request.headers_mut().insert(
-                        hyper::header::AUTHORIZATION,
-                        header);
-                },
-                _ => {}
-            }
-        }
-
-        let mut response = client_service.call((request, context.clone()))
-            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
-
-        match response.status().as_u16() {
-            200 => {
-                let body = response.into_body();
-                let body = body
-                        .to_raw()
-                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
-                let body = str::from_utf8(&body)
-                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Parish>(body)?;
-                Ok(GetAllParishesResponse::SuccessfulOperation
-                    (body)
-                )
-            }
-            400 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllParishesResponse::InvalidIDSupplied
-                )
-            }
-            404 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllParishesResponse::ParishNotFound
-                )
-            }
-            code => {
-                let headers = response.headers().clone();
-                let body = response.into_body()
-                       .take(100)
-                       .to_raw().await;
-                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
-                    code,
-                    headers,
-                    match body {
-                        Ok(body) => match String::from_utf8(body) {
-                            Ok(body) => body,
-                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
-                        },
-                        Err(e) => format!("<Failed to read body: {}>", e),
-                    }
-                )))
-            }
-        }
-    }
-
     async fn get_parish_by_id(
         &self,
         param_id: uuid::Uuid,
@@ -1803,7 +1669,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/parish/{id}",
+            "{}/query-api/parishes/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -1902,17 +1768,144 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
+    async fn get_parishes(
+        &self,
+        param_diocese_name: Option<String>,
+        param_diocese_id: Option<uuid::Uuid>,
+        param_name: Option<String>,
+        param_offset: Option<uuid::Uuid>,
+        param_count: Option<i32>,
+        context: &C) -> Result<GetParishesResponse, ApiError>
+    {
+        let mut client_service = self.client_service.clone();
+        let mut uri = format!(
+            "{}/query-api/parishes",
+            self.base_path
+        );
+
+        // Query parameters
+        let query_string = {
+            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
+            if let Some(param_diocese_name) = param_diocese_name {
+                query_string.append_pair("dioceseName",
+                    &param_diocese_name.to_string());
+            }
+            if let Some(param_diocese_id) = param_diocese_id {
+                query_string.append_pair("dioceseId",
+                    &param_diocese_id.to_string());
+            }
+            if let Some(param_name) = param_name {
+                query_string.append_pair("name",
+                    &param_name.to_string());
+            }
+            if let Some(param_offset) = param_offset {
+                query_string.append_pair("offset",
+                    &param_offset.to_string());
+            }
+            if let Some(param_count) = param_count {
+                query_string.append_pair("count",
+                    &param_count.to_string());
+            }
+            query_string.finish()
+        };
+        if !query_string.is_empty() {
+            uri += "?";
+            uri += &query_string;
+        }
+
+        let uri = match Uri::from_str(&uri) {
+            Ok(uri) => uri,
+            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
+        };
+
+        let mut request = match Request::builder()
+            .method("GET")
+            .uri(uri)
+            .body(Body::empty()) {
+                Ok(req) => req,
+                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
+        };
+
+        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
+        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
+        });
+
+        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
+            // Currently only authentication with Basic and Bearer are supported
+            match auth_data {
+                &AuthData::Bearer(ref bearer_header) => {
+                    let auth = swagger::auth::Header(bearer_header.clone());
+                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
+                        Ok(h) => h,
+                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
+                    };
+                    request.headers_mut().insert(
+                        hyper::header::AUTHORIZATION,
+                        header);
+                },
+                _ => {}
+            }
+        }
+
+        let mut response = client_service.call((request, context.clone()))
+            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
+
+        match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                let body = body
+                        .to_raw()
+                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
+                let body = str::from_utf8(&body)
+                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
+                let body = serde_json::from_str::<models::Parish>(body)?;
+                Ok(GetParishesResponse::SuccessfulOperation
+                    (body)
+                )
+            }
+            400 => {
+                let body = response.into_body();
+                Ok(
+                    GetParishesResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    GetParishesResponse::ParishNotFound
+                )
+            }
+            code => {
+                let headers = response.headers().clone();
+                let body = response.into_body()
+                       .take(100)
+                       .to_raw().await;
+                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
+                    code,
+                    headers,
+                    match body {
+                        Ok(body) => match String::from_utf8(body) {
+                            Ok(body) => body,
+                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
+                        },
+                        Err(e) => format!("<Failed to read body: {}>", e),
+                    }
+                )))
+            }
+        }
+    }
+
     async fn update_parish(
         &self,
-        param_id: uuid::Uuid,
         param_parish: Option<models::Parish>,
         context: &C) -> Result<UpdateParishResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/parish/{id}",
+            "{}/mutation-api/parish",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
