@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.1.1";
+pub const API_VERSION: &'static str = "0.1.3";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -31,7 +31,7 @@ pub enum DeleteDeaneryResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetAllDeaneriesResponse {
+pub enum GetDeaneriesResponse {
     /// successful operation
     SuccessfulOperation
     (models::Deanery)
@@ -93,7 +93,7 @@ pub enum DeleteDioceseResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetAllDiocesesResponse {
+pub enum GetDioceseByIdResponse {
     /// successful operation
     SuccessfulOperation
     (models::Diocese)
@@ -107,7 +107,7 @@ pub enum GetAllDiocesesResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetDioceseByIdResponse {
+pub enum GetDiocesesResponse {
     /// successful operation
     SuccessfulOperation
     (models::Diocese)
@@ -155,7 +155,7 @@ pub enum DeleteParishResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetAllParishesResponse {
+pub enum GetParishByIdResponse {
     /// successful operation
     SuccessfulOperation
     (models::Parish)
@@ -169,7 +169,7 @@ pub enum GetAllParishesResponse {
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
-pub enum GetParishByIdResponse {
+pub enum GetParishesResponse {
     /// successful operation
     SuccessfulOperation
     (models::Parish)
@@ -214,15 +214,14 @@ pub trait Api<C: Send + Sync> {
     /// Delete deanery by ID
     async fn delete_deanery(
         &self,
-        id: uuid::Uuid,
         context: &C) -> Result<DeleteDeaneryResponse, ApiError>;
 
-    /// Get all deaneries
-    async fn get_all_deaneries(
+    /// Get deaneries
+    async fn get_deaneries(
         &self,
-        province: Option<models::EcclesiasticalProvince>,
+        province_name: Option<String>,
         name: Option<String>,
-        context: &C) -> Result<GetAllDeaneriesResponse, ApiError>;
+        context: &C) -> Result<GetDeaneriesResponse, ApiError>;
 
     /// Find deanery by ID
     async fn get_deanery_by_id(
@@ -233,7 +232,6 @@ pub trait Api<C: Send + Sync> {
     /// Update an existing deanery
     async fn update_deanery(
         &self,
-        id: uuid::Uuid,
         deanery: models::Deanery,
         context: &C) -> Result<UpdateDeaneryResponse, ApiError>;
 
@@ -246,26 +244,24 @@ pub trait Api<C: Send + Sync> {
     /// Delete diocese by ID
     async fn delete_diocese(
         &self,
-        id: uuid::Uuid,
         context: &C) -> Result<DeleteDioceseResponse, ApiError>;
 
-    /// Get all dioceses
-    async fn get_all_dioceses(
-        &self,
-        province: Option<models::EcclesiasticalProvince>,
-        name: Option<String>,
-        context: &C) -> Result<GetAllDiocesesResponse, ApiError>;
-
     /// Find diocese by ID
     async fn get_diocese_by_id(
         &self,
         id: uuid::Uuid,
         context: &C) -> Result<GetDioceseByIdResponse, ApiError>;
 
+    /// Get all dioceses
+    async fn get_dioceses(
+        &self,
+        province_name: Option<String>,
+        name: Option<String>,
+        context: &C) -> Result<GetDiocesesResponse, ApiError>;
+
     /// Update an existing diocese
     async fn update_diocese(
         &self,
-        id: uuid::Uuid,
         diocese: models::Diocese,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>;
 
@@ -278,28 +274,27 @@ pub trait Api<C: Send + Sync> {
     /// Delete parish by ID
     async fn delete_parish(
         &self,
-        id: uuid::Uuid,
         context: &C) -> Result<DeleteParishResponse, ApiError>;
 
-    /// Get all parishes
-    async fn get_all_parishes(
-        &self,
-        diocese: Option<models::Diocese>,
-        name: Option<String>,
-        offset: Option<uuid::Uuid>,
-        count: Option<i32>,
-        context: &C) -> Result<GetAllParishesResponse, ApiError>;
-
     /// Find parish by ID
     async fn get_parish_by_id(
         &self,
         id: uuid::Uuid,
         context: &C) -> Result<GetParishByIdResponse, ApiError>;
 
+    /// Get all parishes
+    async fn get_parishes(
+        &self,
+        diocese_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
+        name: Option<String>,
+        offset: Option<uuid::Uuid>,
+        count: Option<i32>,
+        context: &C) -> Result<GetParishesResponse, ApiError>;
+
     /// Update an existing parish
     async fn update_parish(
         &self,
-        id: uuid::Uuid,
         parish: Option<models::Parish>,
         context: &C) -> Result<UpdateParishResponse, ApiError>;
 
@@ -322,15 +317,14 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Delete deanery by ID
     async fn delete_deanery(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteDeaneryResponse, ApiError>;
 
-    /// Get all deaneries
-    async fn get_all_deaneries(
+    /// Get deaneries
+    async fn get_deaneries(
         &self,
-        province: Option<models::EcclesiasticalProvince>,
+        province_name: Option<String>,
         name: Option<String>,
-        ) -> Result<GetAllDeaneriesResponse, ApiError>;
+        ) -> Result<GetDeaneriesResponse, ApiError>;
 
     /// Find deanery by ID
     async fn get_deanery_by_id(
@@ -341,7 +335,6 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Update an existing deanery
     async fn update_deanery(
         &self,
-        id: uuid::Uuid,
         deanery: models::Deanery,
         ) -> Result<UpdateDeaneryResponse, ApiError>;
 
@@ -354,26 +347,24 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Delete diocese by ID
     async fn delete_diocese(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteDioceseResponse, ApiError>;
 
-    /// Get all dioceses
-    async fn get_all_dioceses(
-        &self,
-        province: Option<models::EcclesiasticalProvince>,
-        name: Option<String>,
-        ) -> Result<GetAllDiocesesResponse, ApiError>;
-
     /// Find diocese by ID
     async fn get_diocese_by_id(
         &self,
         id: uuid::Uuid,
         ) -> Result<GetDioceseByIdResponse, ApiError>;
 
+    /// Get all dioceses
+    async fn get_dioceses(
+        &self,
+        province_name: Option<String>,
+        name: Option<String>,
+        ) -> Result<GetDiocesesResponse, ApiError>;
+
     /// Update an existing diocese
     async fn update_diocese(
         &self,
-        id: uuid::Uuid,
         diocese: models::Diocese,
         ) -> Result<UpdateDioceseResponse, ApiError>;
 
@@ -386,28 +377,27 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Delete parish by ID
     async fn delete_parish(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteParishResponse, ApiError>;
 
-    /// Get all parishes
-    async fn get_all_parishes(
-        &self,
-        diocese: Option<models::Diocese>,
-        name: Option<String>,
-        offset: Option<uuid::Uuid>,
-        count: Option<i32>,
-        ) -> Result<GetAllParishesResponse, ApiError>;
-
     /// Find parish by ID
     async fn get_parish_by_id(
         &self,
         id: uuid::Uuid,
         ) -> Result<GetParishByIdResponse, ApiError>;
 
+    /// Get all parishes
+    async fn get_parishes(
+        &self,
+        diocese_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
+        name: Option<String>,
+        offset: Option<uuid::Uuid>,
+        count: Option<i32>,
+        ) -> Result<GetParishesResponse, ApiError>;
+
     /// Update an existing parish
     async fn update_parish(
         &self,
-        id: uuid::Uuid,
         parish: Option<models::Parish>,
         ) -> Result<UpdateParishResponse, ApiError>;
 
@@ -449,22 +439,21 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Delete deanery by ID
     async fn delete_deanery(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteDeaneryResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().delete_deanery(id, &context).await
+        self.api().delete_deanery(&context).await
     }
 
-    /// Get all deaneries
-    async fn get_all_deaneries(
+    /// Get deaneries
+    async fn get_deaneries(
         &self,
-        province: Option<models::EcclesiasticalProvince>,
+        province_name: Option<String>,
         name: Option<String>,
-        ) -> Result<GetAllDeaneriesResponse, ApiError>
+        ) -> Result<GetDeaneriesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_all_deaneries(province, name, &context).await
+        self.api().get_deaneries(province_name, name, &context).await
     }
 
     /// Find deanery by ID
@@ -480,12 +469,11 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Update an existing deanery
     async fn update_deanery(
         &self,
-        id: uuid::Uuid,
         deanery: models::Deanery,
         ) -> Result<UpdateDeaneryResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_deanery(id, deanery, &context).await
+        self.api().update_deanery(deanery, &context).await
     }
 
     /// Add new diocese
@@ -501,22 +489,10 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Delete diocese by ID
     async fn delete_diocese(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteDioceseResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().delete_diocese(id, &context).await
-    }
-
-    /// Get all dioceses
-    async fn get_all_dioceses(
-        &self,
-        province: Option<models::EcclesiasticalProvince>,
-        name: Option<String>,
-        ) -> Result<GetAllDiocesesResponse, ApiError>
-    {
-        let context = self.context().clone();
-        self.api().get_all_dioceses(province, name, &context).await
+        self.api().delete_diocese(&context).await
     }
 
     /// Find diocese by ID
@@ -529,15 +505,25 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().get_diocese_by_id(id, &context).await
     }
 
+    /// Get all dioceses
+    async fn get_dioceses(
+        &self,
+        province_name: Option<String>,
+        name: Option<String>,
+        ) -> Result<GetDiocesesResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().get_dioceses(province_name, name, &context).await
+    }
+
     /// Update an existing diocese
     async fn update_diocese(
         &self,
-        id: uuid::Uuid,
         diocese: models::Diocese,
         ) -> Result<UpdateDioceseResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_diocese(id, diocese, &context).await
+        self.api().update_diocese(diocese, &context).await
     }
 
     /// Add new parish
@@ -553,24 +539,10 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Delete parish by ID
     async fn delete_parish(
         &self,
-        id: uuid::Uuid,
         ) -> Result<DeleteParishResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().delete_parish(id, &context).await
-    }
-
-    /// Get all parishes
-    async fn get_all_parishes(
-        &self,
-        diocese: Option<models::Diocese>,
-        name: Option<String>,
-        offset: Option<uuid::Uuid>,
-        count: Option<i32>,
-        ) -> Result<GetAllParishesResponse, ApiError>
-    {
-        let context = self.context().clone();
-        self.api().get_all_parishes(diocese, name, offset, count, &context).await
+        self.api().delete_parish(&context).await
     }
 
     /// Find parish by ID
@@ -583,15 +555,28 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().get_parish_by_id(id, &context).await
     }
 
+    /// Get all parishes
+    async fn get_parishes(
+        &self,
+        diocese_name: Option<String>,
+        diocese_id: Option<uuid::Uuid>,
+        name: Option<String>,
+        offset: Option<uuid::Uuid>,
+        count: Option<i32>,
+        ) -> Result<GetParishesResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().get_parishes(diocese_name, diocese_id, name, offset, count, &context).await
+    }
+
     /// Update an existing parish
     async fn update_parish(
         &self,
-        id: uuid::Uuid,
         parish: Option<models::Parish>,
         ) -> Result<UpdateParishResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().update_parish(id, parish, &context).await
+        self.api().update_parish(parish, &context).await
     }
 
 }
